(function($){
	var consulting = {
        getList: function(data){
            return APIService.httpGet('/im_new/consult/getList', data);
        },
        getListTableAjaxObj: { //表格数据获取时，使用的ajax请求配置
            method: 'get',
            url: APIService.server + 'im_new/consult/getList', 
            contentType: "application/json",
            dataType: "json",
            ajaxOptions: {
                beforeSend: function(request) {
                    var userAgent = APIService.userAgent;
                    userAgent = JSON.stringify(userAgent);
                    request.setRequestHeader("userAgent", userAgent);
                }
            }
        },
        getListCount: function(data){
            return APIService.httpGet('/im_new/consult/getListCount', data);
        },
        getConsultStatus: function(data){
            return APIService.httpGet('doctor/consult/getConsultStatus', data);
        },
        getPrescriptionInfo: function(data){
            return APIService.httpGet('/doctor/consult/prescriptionDetail', data);
        },
        uploadImage: function(data){
            return APIService.httpPost('upload/chat', data);
        },
        getPatientServiceType: function(data){
            return APIService.httpGet('doctor/sign/getPatientFamilyServer', data);
        },
        finishConsult: function(data){
            return APIService.httpPost('doctor/consult/finish_consult', data);
        },
        //IM相关的接口
        socketUrl: APIService.imserver+'/socket.io/socket.io.js',
        getMessages: function(sessionId, data){
            return APIService.imHttpGet('/sessions/'+sessionId+'/messages', data);
        },
        sendMessage: function(sessionId, data){
            return APIService.imHttpPost('/sessions/'+sessionId+'/messages', data);
        },
        getMembers: function(sessionId){
            return APIService.imHttpGet('/sessions/'+sessionId+'/participants');
        },
        //通过续方code,获得续方详情
        getPrescriptionInfoByCode: function(data){
            return APIService.httpGet('doctor/prescriptionInfo/getContinuedPrescriptionAsDoctor', data);
        }
    };

    window.consultingAPI = consulting;
})(jQuery)
